import { Injectable } from '@nestjs/common'
import { CreateGeolocationDto } from './dto/create-geolocation.dto'
import { PrismaService } from 'src/prisma/prisma.service'
import { Geolocation, User } from '@prisma/client'
import { QueryPaginationDto } from 'src/common/dto/pagination-query.dto'
import { paginate } from 'src/common/utils/pagination.utils'

@Injectable()
export class GeolocationsService {
  constructor(private prisma: PrismaService) { }

  async create(authenticatedUser: User, createGeolocationDto: CreateGeolocationDto): Promise<Geolocation> {
    const data = { ...createGeolocationDto, userId: authenticatedUser.id }
    return await this.prisma.geolocation.create({ data: data })
  }

  async findAll(queryPagination?: QueryPaginationDto): Promise<[Geolocation[], number]> {
    return [
      await this.prisma.geolocation.findMany({
        ...paginate(queryPagination),
      }),
      await this.prisma.geolocation.count(),
    ]
  }

  async findOne(id: number): Promise<Geolocation> {
    return await this.prisma.geolocation.findUnique({ where: { id } })
  }


  async remove(id: number): Promise<Geolocation> {
    return await this.prisma.geolocation.delete({ where: { id } })
  }
}
